<?xml version="1.0"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:saxon="http://icl.com/saxon" xmlns:graph="graph" xmlns:results="results" extension-element-prefixes="saxon">

    <!-- =================  print build errors menu ============================ -->
    
    <xsl:template name="display_goals_menu">
    
    <xsl:if test="($goals) > 0">
    <xsl:call-template name="display_linked_menu_item">
  	 <xsl:with-param name="text" select="$RES_PARAMETER_GOALS" />
     <xsl:with-param name="link" select="'#goals_hd'" />
    </xsl:call-template>           
    </xsl:if>
    
    </xsl:template>

    <!-- =================  print goals ============================ -->
    
    <xsl:template name="display_goals">
    
    <xsl:if test="($goals) > 0">
    <br/>
    <xsl:call-template name="goals_header"/>
    
    <xsl:if test="($generate_graphs = 'true')">
        <xsl:if test="($goals_history) > 0">
        <br/>
            <xsl:call-template name="generate_graph">
                <xsl:with-param name="graph" select="/ResultsSession/Goals/History/Graph[@id=$goals_graph_id]"/>
                <xsl:with-param name="img_name" select="concat('goals_',$org_time)"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:if>
    <br/>    
    <xsl:call-template name="goals_summary"/>
    <br/>
    
    </xsl:if>

    </xsl:template>    
    
    <!-- =================  print goals header ============================ -->
    
    <xsl:template name="goals_header">
        <a name="goals_hd"/>
        <table width="{$width}" cellpadding="0" cellspacing="0">
            <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">15% 70% 15%</xsl:attribute>
            </xsl:if>
            <tr>               
                <td width="15%"></td>
                <td align="center">                    
                    <div class="header" ><xsl:value-of select="$RES_PARAMETER_GOALS"/></div>
                </td>
                <td width="15%" align="right" valign="bottom">
	  	           <xsl:if test="not($report_type = $email_report) and ($first_back_to_top = 'false')">
                      <xsl:call-template name="back_to_top"/>
                   </xsl:if>
   		           <saxon:assign name="first_back_to_top">false</saxon:assign>
                </td>
            </tr>
        </table>
    </xsl:template>
       
    <!-- =================  print goals summary ============================ -->
    
    <xsl:template name="goals_summary">
    
        <table class="singleborder" width='{$width}' bordercolor='{$goals_bdrcolor}' cellpadding='0' cellspacing='0'>
            <xsl:if test="($report_format_mode='pdf')">
        
                <xsl:if test="$goals_history > 0">
                    <xsl:attribute name="cols">60% 20% 20%</xsl:attribute>
                </xsl:if>
                <xsl:if test="$goals_history = 0">
                    <xsl:attribute name="cols">50% 50%</xsl:attribute>            
                </xsl:if>
             </xsl:if>
        
            <tr bgcolor="{$goals_bcolor}">
                <td class="singleborder" width="50%" align="center">
                    <b><xsl:value-of select="$RES_PARAMETER_GOAL_NAME"/></b><br/>
                    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                </td>
                
                <td class="singleborder" align='center'>
                    <xsl:if test="$goals_history > 0">
                        <xsl:attribute name="colspan">2</xsl:attribute>
                    </xsl:if>
                    <b><xsl:value-of select="$RES_PARAMETER_RECOMMENDED_TASKS"/></b><br/>
    
                    <xsl:if test="$goals_history > 0">
                        <xsl:value-of select="$RES_PARAMETER_DELTA_TOTAL"/><xsl:value-of 
                        select="($nbsp)" disable-output-escaping="yes"/>/<xsl:value-of 
                        select="($nbsp)" disable-output-escaping="yes"/>
                    </xsl:if>
                    <xsl:value-of select="$RES_PARAMETER_TOTAL_LOWERCASE"/>
                </td>
            </tr>
            <xsl:call-template name="goals_list"/>
        </table>
    
    </xsl:template>
    
    <!-- =================  print goals list ============================ -->
    
    <xsl:template name="goals_list">
        
        <xsl:for-each select="/ResultsSession/Goals/Goal[@active = 'true']">
        
        <tr>
            <td class="singleborder" align="left">
            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            <xsl:value-of select="@name"/>
            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            </td>   

            <xsl:if test="$goals_history > 0">
                <td class="singleborder" align="right">
                    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                    <xsl:call-template name="format_delta_position">
                        <xsl:with-param name="delta" select="/ResultsSession/Goals/History/Graph[@id=$goals_graph_id]/Total/Delta"/>
                        <xsl:with-param name="position" select="position()-1"/>
                    </xsl:call-template>
                    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                </td>   
            </xsl:if>
    
            <td class="singleborder" align="right">
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                <xsl:value-of select="@tsks"/>
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            </td>   
        </tr>        
        
        </xsl:for-each>
                
        <tr>
            <td class="singleborder" align="left">
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                <b><xsl:value-of select="($RES_PARAMETER_TOTAL)"/></b>
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            </td>
            <xsl:if test="$goals_history > 0">
                <td class="singleborder" align="right">
                    
                    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                    <xsl:call-template name="format_delta_position">
                        <xsl:with-param name="delta" select="/ResultsSession/Goals/History/Graph[@id=$goals_graph_id]/Total/Delta"/>
                        <xsl:with-param name="position" select="count(/ResultsSession/Goals/Goal[@active = 'true'])"/>
                    </xsl:call-template>
                    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                </td>   
            </xsl:if>
    
            <td class="singleborder" align="right">
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                <xsl:value-of select="/ResultsSession/Goals/@tsks"/>
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            </td>   
        </tr>
  
    </xsl:template>         
     
</xsl:stylesheet>
